@@ -215,12 +215,13 @@ def invoke_dcut(args):
                     args.upload_file
                 ))
             upload_path = args.upload_file
+            upload_filename = os.path.basename(args.upload_file)
         else:
-            fh = tempfile.NamedTemporaryFile(mode='w+r', delete=False)
+            fh = tempfile.NamedTemporaryFile(mode='w+', delete=False)
             (name, email) = write_header(fh, profile, args)
             command.produce(fh, args)
             fh.flush()
-            #print fh.name
+            #print(fh.name)
             fh.close()
 
             if args.save:
