@@ -26,7 +26,8 @@ from dput.uploader import AbstractUploader
 from dput.core import logger
 
 import mmap
-import urllib
+import urllib.parse
+import urllib.request
 import os.path
 import mimetypes
 
@@ -58,7 +59,8 @@ class HTTPUploader(AbstractUploader):
         # urlparse library. Pretty please. Hopefully the mangling below is
         # reasonably sane
         if not self._config['fqdn'].lower().startswith("http"):
-            self._config['fqdn'] = "http://" + self._config['fqdn']
+            self._config['fqdn'] = "{}://{}".format(
+                self._config['method'], self._config['fqdn'])
         self._baseurl = urllib.parse.urlparse(self._config['fqdn'])
 
         _incoming = self._config['incoming']
@@ -95,13 +97,24 @@ class HTTPUploader(AbstractUploader):
         (mime_type, _) = mimetypes.guess_type(filename)
         fh = open(filename, 'rb')
         mmaped_fh = mmap.mmap(fh.fileno(), 0, access=mmap.ACCESS_READ)
-        req = urllib.request.Request(url=upload_filename, data=mmaped_fh)
-        req.add_header("Content-Type", mime_type)
-        req.get_method = lambda: 'PUT'
+        req = urllib.request.Request(
+            url=upload_filename,
+            data=fh.read(),
+            method='PUT',
+        )
+        if mime_type is not None:
+            req.add_header("Content-Type", mime_type)
 
         try:
             urllib.request.urlopen(req)
         except urllib.error.HTTPError as e:
+            error_message = e.read().decode(
+                e.headers.get_content_charset(failobj='utf-8'))
+            if error_message:
+                error_message = error_message.strip()
+                if "\n" in error_message:
+                    error_message = "\n\t" + "\n\t".join(error_message.splitlines())
+                logger.warning("HTTP error message: %s" % error_message)
             if e.code == 403:
                 self.upload_write_error(e)
             else:
